@@ -15,7 +15,7 @@ use CodeGen::Protection::Types qw(
   Optional
 );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our @EXPORT_OK = qw(
   create_protected_code
   rewrite_code
@@ -73,7 +73,7 @@ CodeGen::Protection - Safely rewrite parts of generated code
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -100,10 +100,10 @@ Code that writes code can be a powerful tool, especially when you need to
 generate lots of boilerplate. However, when a developer takes the generated
 code, they can easily rewrite that code in a way that no longer works, or make
 good changes that get wiped out if the code is regenerated.
-L<https://metacpan.org/pod/DBIx::Class::Schema::Loader> protects against this
-by marking blocks of code with start and end comments and an MD5 checksum. If
-you change any of the code between those comments, regenerating your schema
-will fail.
+L<DBIx::Class::Schema::Loader|https://metacpan.org/pod/DBIx::Class::Schema::Loader>
+protects against this by marking blocks of code with start and end comments
+and an MD5 checksum. If you change any of the code between those comments,
+regenerating your schema will fail.
 
 This module takes this idea and generalizes it. It allows you to do a safe
 partial rewrite of documents. At the present time, we support Perl and HTML.
@@ -228,14 +228,12 @@ There are two modes: "Creation" and "Rewrite."
 
 =head2 Creation Mode
 
-    my $rewrite = CodeGen::Protection::Perl->new(
+    my $protected_code = create_protected_code(
         protected_code => $text,
     );
-    say $rewrite->rewritten;
 
-If you create an instance with C<protected_code> but not old text, this will wrap
-the new text in start and end tags that "protect" the document if you rewrite
-it:
+This will wrap the new text in start and end tags that "protect" the document
+if you rewrite it:
 
     my $perl = <<'END';
     sub sum {
@@ -244,12 +242,11 @@ it:
         return $total;
     }
     END
-    my $rewrite = CodeGen::Protection::Perl->new( protected_code => $perl );
-    say $rewrite->rewritten;
+    my $protected_code = protected_code( protected_code => $perl );
 
-Output:
+Result:
 
-    #<<< CodeGen::Protection::Perl 0.01. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #<<< CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
 
     sub sum {
         my $total = 0;
@@ -257,7 +254,7 @@ Output:
         return $total;
     }
 
-    #>>> CodeGen::Protection::Perl 0.01. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #>>> CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
 
 You can then take the marked up document and insert it into another Perl
 document and use the rewrite mode to safely rewrite the code between the start
@@ -278,11 +275,10 @@ marked up document and insert it into another Perl document and use the
 rewrite mode to safely rewrite the code between the start and end markers.
 The rest of the document will be ignored.
 
-    my $rewrite = CodeGen::Protection::Perl->new(
-        existing_code => $existing_code,
+    my $rewrite = rewrite_code(
+        existing_code  => $existing_code,
         protected_code => $protected_code,
     );
-    say $rewrite->rewritten;
 
 In the above, assuming that C<$existing_code> is a rewritable document, the
 C<$protected_code> will replace the rewritable section of the C<$existing_code>, leaving
@@ -304,7 +300,7 @@ like this:
         return sum(@_)/@_;
     }
 
-    #<<< CodeGen::Protection::Perl 0.01. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #<<< CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the end comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
 
     sub sum {
         my $total = 0;
@@ -312,13 +308,13 @@ like this:
         return $total;
     }
 
-    #>>> CodeGen::Protection::Perl 0.01. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
+    #>>> CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the start comment. Checksum: fa97a021bd70bf3b9fa3e52f203f2660
     
     1;
 
 However, later on I might realize that the C<sum> function will happily try to
-sum things which are not numbers, so I want to fix that. I'll slurp the C<My::Package> code
-into the C<$existing_code> variable and then:
+sum things which are not numbers, so I want to fix that. I'll slurp the
+C<My::Package> code into the C<$existing_code> variable and then:
 
     my $perl = <<'END';
     use Scalar::Util 'looks_like_number';
@@ -334,10 +330,9 @@ into the C<$existing_code> variable and then:
         return $total;
     }
     END
-    my $rewrite = CodeGen::Protection::Perl->new( existing_code => $existing_code, protected_code => $perl );
-    say $rewrite->rewritten;
+    my $rewrite = rewrite_code( existing_code => $existing_code, protected_code => $perl );
 
-And that will print out:
+And that will result in:
 
     package My::Package;
     
@@ -348,7 +343,7 @@ And that will print out:
         return sum(@_)/@_;
     }
     
-    #<<< CodeGen::Protection::Perl 0.01. Do not touch any code between this and the end comment. Checksum: d135a051f158ee19fbd68af5466fb1ae
+    #<<< CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the end comment. Checksum: d135a051f158ee19fbd68af5466fb1ae
     
     use Scalar::Util 'looks_like_number';
     
@@ -363,7 +358,7 @@ And that will print out:
         return $total;
     }
     
-    #>>> CodeGen::Protection::Perl 0.01. Do not touch any code between this and the start comment. Checksum: d135a051f158ee19fbd68af5466fb1ae
+    #>>> CodeGen::Protection::Format::Perl 0.03. Do not touch any code between this and the start comment. Checksum: d135a051f158ee19fbd68af5466fb1ae
     
     1;
 
@@ -373,6 +368,8 @@ rewritten, while the rest of the code remains unchanged.
 =head1 ACKNOWLEDGEMENTS
 
 We would like to thank L<All Around the World|https://allaroundtheworld.fr/>
+
+Thanks to Matt Trout (mst) for the inspiration from the schema loader.
 for sponsoring this work.
 
 =head1 AUTHOR
